numpy.memmap
============

.. currentmodule:: numpy

.. autoclass:: memmap

   

   .. HACK
      .. autosummary::
         :toctree:
      
         memmap.__init__
         memmap.all
         memmap.any
         memmap.argmax
         memmap.argmin
         memmap.argsort
         memmap.astype
         memmap.byteswap
         memmap.choose
         memmap.clip
         memmap.compress
         memmap.conj
         memmap.conjugate
         memmap.copy
         memmap.cumprod
         memmap.cumsum
         memmap.diagonal
         memmap.dot
         memmap.dump
         memmap.dumps
         memmap.fill
         memmap.flatten
         memmap.flush
         memmap.getfield
         memmap.item
         memmap.itemset
         memmap.max
         memmap.mean
         memmap.min
         memmap.newbyteorder
         memmap.nonzero
         memmap.prod
         memmap.ptp
         memmap.put
         memmap.ravel
         memmap.repeat
         memmap.reshape
         memmap.resize
         memmap.round
         memmap.searchsorted
         memmap.setasflat
         memmap.setfield
         memmap.setflags
         memmap.sort
         memmap.squeeze
         memmap.std
         memmap.sum
         memmap.swapaxes
         memmap.take
         memmap.tofile
         memmap.tolist
         memmap.tostring
         memmap.trace
         memmap.transpose
         memmap.var
         memmap.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         memmap.T
         memmap.base
         memmap.ctypes
         memmap.data
         memmap.dtype
         memmap.flags
         memmap.flat
         memmap.imag
         memmap.itemsize
         memmap.nbytes
         memmap.ndim
         memmap.real
         memmap.shape
         memmap.size
         memmap.strides

